@@ -3,11 +3,14 @@
 from web3 import Web3
 from eth_abi import encode_single, encode_abi
 from eth_account import Account
-from ..utils import helper
 import secrets
 import requests
 import json
 import math
+import os
+
+from ..utils import helper
+from RupineHeroku.rupine_db import herokuCredentials, herokuAbi
 
 headers = {
     'User-Agent': 'NMask User Agent 1.0',
@@ -339,4 +342,26 @@ def get_liquidity_pool_address(w3:Web3,swap_contract_address:str,swap_contract_a
     except Exception as e:
         return None
 
+def getABI(connection, schema, contract_address:str,chain_id:int):
+    if not Web3.isAddress(contract_address):
+        return None
+    #filename = '{0}_{1}.json'.format(str(chain_id),contract_address)
+    
+    result = herokuAbi.getAbi(connection, schema, contract_address, chain_id)
+    data = []
+
+    if result:
+        return result
+    else:
+        if chain_id in [1,3,4]:
+            api_key = herokuCredentials.getCredential(connection, schema, 'Etherscan DEV','API KEY', 1) 
+        else:
+            api_key = herokuCredentials.getCredential(connection, schema, 'BSCScan DEV','API KEY', 56) 
+        abi = get_contract_abi_by_eth_or_bsc_scan(contract_address,chain_id,api_key)
+        if abi != None:
+            herokuAbi.updateAbi(connection, schema, abi, Web3.toChecksumAddress(contract_address), chain_id)
+            #write_to_file(os.environ.get('ABI_LOCATION'),filename,abi)
+        return abi
+
+
         
\ No newline at end of file
