@@ -1,7 +1,7 @@
 from itertools import chain
 import os
 from web3 import Web3
-from RupineHeroku import herokuCredentials
+from RupineHeroku.rupine_db import herokuCredentials
 
 def GetProviderAnkr(chain_id, connection, schema):
     username = herokuCredentials.getCredential(connection, schema, "Ankr PROD", "USERNAME", 1) 
